# CONSTANTS
BesselFilter = 14
CompareAnyLayer = 2
OverlayCompositeOp = 41
X11Event = 32768
MagickQuantumFormatOptions = 37
AllValues = 2147483647
OpacityQuantum = 13
UndefinedTransmitType = 0

UndefinedColorspace = 0
RGBColorspace = 1
GRAYColorspace = 2
TransparentColorspace = 3
OHTAColorspace = 4
LabColorspace = 5
MagickColorspaceOptions = 6
XYZColorspace = 6
YCbCrColorspace = 7
YCCColorspace = 8
YIQColorspace = 9
YPbPrColorspace = 10
YUVColorspace = 11
CMYKColorspace = 12
sRGBColorspace = 13
HSBColorspace = 14
HSLColorspace = 15
HWBColorspace = 16
Rec601LumaColorspace = 17
Rec601YCbCrColorspace = 18
Rec709LumaColorspace = 19
Rec709YCbCrColorspace = 20
LogColorspace = 21
CMYColorspace = 22


LosslessJPEGCompression = 7
__GCONV_NOCONV = 1
ActivateAlphaChannel = 1
MagickStorageOptions = 40
DstInCompositeOp = 23
RoundJoin = 2
RollPreview = 3
OpacityChannel = 8
TopLeftOrientation = 1
LongPixel = 5
MaxEvaluateOperator = 5
UndefinedDistortion = 0
__GCONV_NOMEM = 3
LeftBottomOrientation = 8
UndefinedQuantumFormat = 0
NonZeroRule = 2
__GCONV_FULL_OUTPUT = 5
BicubicInterpolatePixel = 2
QuadraticFilter = 9
DiskResource = 2
MagickVirtualPixelOptions = 44
StreamFatalError = 740
IndexAlphaQuantum = 10
ReplaceCompositeOp = 43
ChangeMaskCompositeOp = 6
HeightValue = 8
ImageFatalError = 765
UltraExpandedStretch = 9
EdgeVirtualPixelMethod = 4
NormalStretch = 1
ShortPixel = 7
SetAlphaChannel = 4
ArcDistortion = 3
AffineProjectionDistortion = 2
__codecvt_partial = 1
MultiplicativeGaussianNoise = 3
UndefinedSpread = 0
EncoderThreadSupport = 2
UndefinedStretch = 0
DstAtopCompositeOp = 21
TypeFatalError = 705
WarningException = 300
MagickImageFilterModule = 1
MinEvaluateOperator = 6
TrueColorType = 6
UndefinedTimerState = 0
MagickDelegateOptions = 48
UndefinedGravity = 0
SaturationIntent = 1
OptimizePlusLayer = 8
RoundRectanglePrimitive = 4
OptionFatalError = 710
ResourceLimitWarning = 300
ConcatenateMode = 3
MagickMetricOptions = 29
FileTransmitType = 1
MagentaQuantum = 12
ScreenCompositeOp = 45
UndefinedClass = 0
UndefinedRule = 0
UserEvent = 8192
SemiExpandedStretch = 6
UndefinedPixel = 0
EvenOddRule = 1
UndefinedJoin = 0
AnnotateEvent = 2
TailPath = 4
PixelsPerCentimeterResolution = 2
AnyStretch = 10
ImpulseNoise = 4
MagickComposeOptions = 8
TopRightOrientation = 2
IntegerPixel = 4
MagickMimeOptions = 51
GrayscaleMatteType = 3
ImplodePreview = 25
CopyGreenCompositeOp = 15
PathPrimitive = 15
PeakSignalToNoiseRatioMetric = 6
UndefinedCompliance = 0
TriangleFilter = 3
LineInterlace = 2
GaussianFilter = 8
StaticGravity = 10
ShadePreview = 21
MosaicLayer = 15
CMYKAQuantum = 4
UndefinedPrimitive = 0
FilterInterpolatePixel = 4
PolygonPrimitive = 9
RGBAQuantum = 15
ResourceEvent = 2048
FloatingPointQuantumFormat = 1
MagickLineJoinOptions = 26
DisposeLayer = 5
RedQuantum = 14
MissingDelegateWarning = 320
XServerError = 480
CopyCyanCompositeOp = 14
MagickChannelOptions = 3
JPEGCompression = 5
MultiplyEvaluateOperator = 7
DefaultChannels = 247
BlobError = 435
ForgetGravity = 0
__codecvt_ok = 0
SquareCap = 3
SubimagePath = 7
MagickPreviewOptions = 35
RandomNoise = 7
__codecvt_error = 2
UndefinedChannel = 0
MeanSquaredErrorMetric = 4
UndefinedInterpolatePixel = 0
CubicFilter = 10
CorruptImageFatalError = 725
RemoveDupsLayer = 10
ObliqueStyle = 3
MagickResourceOptions = 39
CatromFilter = 11
CompareClearLayer = 3
ResetMethod = 5
UniformNoise = 1
UndefinedOrientation = 0
RGBOQuantum = 16
SrcInCompositeOp = 49
ExceptionEvent = 256
MagickLayerOptions = 24
FileResource = 3
FloatPixel = 3
UndefinedQuantum = 0
EastGravity = 6
UndefinedResolution = 0
DullPreview = 9
OverlineDecoration = 3
CoderWarning = 350
MagickDisposeOptions = 13
ConstantVirtualPixelMethod = 2
DstOutCompositeOp = 24
SetEvaluateOperator = 10
AbsoluteIntent = 3
AddNoisePreview = 14
DitherVirtualPixelMethod = 3
ParzenFilter = 18
AllCompliance = 2147483647
MagickLocaleOptions = 52
HuePreview = 4
HardLightCompositeOp = 30
__GCONV_EMPTY_INPUT = 4
BlobTransmitType = 2
ImageInfoRegistryType = 2
UndefinedInterlace = 0
LSBEndian = 1
ItalicStyle = 2
UserSpace = 1
BlendCompositeOp = 4
GrayAlphaQuantum = 7
__GCONV_IS_LAST = 1
FlattenLayer = 14
PNGInterlace = 7
DirectClass = 1
XValue = 1
MagickMethodOptions = 30
BoxFilter = 2
PercentValue = 4096
AreaResource = 1
WidthValue = 4
UndefinedEvents = 0
DeactivateAlphaChannel = 2
UltraCondensedStretch = 2
ModuleError = 455
CacheWarning = 345
XNegative = 32
UnsignedQuantumFormat = 3
MagickInterpolateOptions = 23
YellowQuantum = 18
SrcOverCompositeOp = 51
DoublePixel = 2
WavePreview = 26
RedChannel = 1
MagickClassOptions = 4
ExclusionCompositeOp = 29
GaussianNoise = 2
ReadMode = 0
QuantumPixel = 6
MonitorError = 485
PointPrimitive = 1
MagickDecorateOptions = 12
CopyRedCompositeOp = 18
XorEvaluateOperator = 12
LeftAlign = 1
UndefinedIntent = 0
MinusCompositeOp = 36
MagickLogOptions = 53
MatteChannel = 8
AverageInterpolatePixel = 1
AddCompositeOp = 2
__GCONV_OK = 0
BlurPreview = 16
CyanChannel = 1
PeakAbsoluteErrorMetric = 5
TrueColorMatteType = 7
AndEvaluateOperator = 2
FileOpenFatalError = 730
HeadPath = 3
InCompositeOp = 32
HanningFilter = 5
AlphaQuantum = 1
PlaneInterlace = 3
MagickNoiseOptions = 33
SincFilter = 15
CyanQuantum = 6
DifferenceCompositeOp = 26
MagickStyleOptions = 42
YValue = 2
DrawEvent = 128
MagickMogrifyOptions = 32
LessValue = 16384
ColorPrimitive = 11
UndefinedMagickLayerMethod = 0
RaisePreview = 22
ChiValue = 16
NoCompression = 1
BartlettFilter = 21
CenterGravity = 5
ColorBurnCompositeOp = 8
JPEG2000Compression = 6
ModuleFatalError = 755
ThresholdCompositeOp = 53
UndefinedCap = 0
NoInterlace = 1
MissingDelegateFatalError = 720
SplineInterpolatePixel = 8
MagickThresholdOptions = 56
MaskVirtualPixelMethod = 9
YellowChannel = 4
DecoderThreadSupport = 1
LaplacianNoise = 5
ImagePrimitive = 14
MagickTrue = 1
AreaValue = 131072
UndefinedRegistryType = 0
MagickResolutionOptions = 38
RelativeIntent = 4
CopyBlueCompositeOp = 12
LinearLightCompositeOp = 34
EllipsePrimitive = 6
BilinearInterpolatePixel = 3
MergeLayer = 13
PointMethod = 1
SouthWestGravity = 7
UnrecognizedDispose = 0
PolylinePrimitive = 8
GreenQuantum = 9
DissolveCompositeOp = 28
__GCONV_INCOMPLETE_INPUT = 7
MinimumValue = 65536
TextPrimitive = 13
WandFatalError = 770
WandError = 470
RLECompression = 9
XServerFatalError = 780
DivideCompositeOp = 55
AddEvaluateOperator = 1
PaletteBilevelMatteType = 11
MagickDataTypeOptions = 10
SouthGravity = 8
ThresholdPreview = 17
ClearCompositeOp = 7
AllChannels = 255
LuminizeCompositeOp = 35
NoCompositeOp = 1
QuantizePreview = 11
OptionError = 410
ColorSeparationType = 8
MeanErrorPerPixelMetric = 3
OptimizeTransLayer = 9
WandEvent = 16384
MagickIntentOptions = 21
UndefinedMode = 0
ObjectBoundingBox = 3
UndefinedPreview = 0
KaiserFilter = 16
PartitionInterlace = 4
BohmanFilter = 20
DecimalValue = 262144
PreviousDispose = 3
MagickEvaluateOptions = 16
MemoryResource = 5
YNegative = 64
MagickFillRuleOptions = 17
MagickPath = 1
ExtraExpandedStretch = 8
RegistryError = 490
ScaleRotateTranslateDistortion = 7
MiterJoin = 1
BrightnessPreview = 6
SharpenPreview = 15
MagickUndefinedOptions = -1
ColorDodgeCompositeOp = 9
BasePath = 5
RightAlign = 3
MagickAlignOptions = 0
ExtensionPath = 6
CacheError = 445
UndefinedFilter = 0
StreamError = 440
CanonicalPath = 8
BackgroundDispose = 2
ResourceLimitFatalError = 700
StoppedTimerState = 1
NoValue = 0
LeftShiftEvaluateOperator = 4
SentinelFilter = 22
BlueQuantum = 3
PoissonNoise = 6
MagentaChannel = 2
PlusCompositeOp = 42
SwirlPreview = 24
MagickListOptions = 27
BackgroundVirtualPixelMethod = 1
MonitorFatalError = 785
MitchellFilter = 12
DelegateWarning = 315
PseudoClass = 2
RegistryWarning = 390
CoderEvent = 16
MagickCompressOptions = 9
UndefinedPath = 0
EdgeDetectPreview = 18
DrawWarning = 360
GrayChannel = 1
MagickDebugOptions = 11
BilinearDistortion = 4
OptimizeLayer = 6
WandWarning = 370
MagickModuleOptions = 55
RunningTimerState = 2
CompositeLayer = 12
FatalErrorException = 700
ModuleWarning = 355
BlackChannel = 32
XPMCompliance = 4
OptionWarning = 310
AbsoluteErrorMetric = 1
DelegateError = 415
CorruptImageWarning = 325
Group4Compression = 4
JPEGInterlace = 6
MagickColorOptions = 46
__GCONV_ILLEGAL_DESCRIPTOR = 8
RightTopOrientation = 6
PerceptualIntent = 2
LagrangeFilter = 19
WestGravity = 4
UndefinedType = 0
UnderlineDecoration = 2
AnyStyle = 4
FaxCompression = 3
CacheFatalError = 745
CoderError = 450
ColorSeparationMatteType = 9
IOMode = 2
BumpmapCompositeOp = 5
CacheEvent = 8
DrawFatalError = 760
IndexQuantum = 11
SaturateCompositeOp = 44
SignedQuantumFormat = 2
MeanAbsoluteErrorMetric = 2
RepeatSpread = 3
RegistryFatalError = 790
BottomRightOrientation = 3
NoDecoration = 1
ConfigureWarning = 395
UndefinedNoise = 0
MagickFilterOptions = 18
RadialGradient = 2
MagickConfigureOptions = 47
GreenChannel = 2
MagickEndianOptions = 15
PerspectiveProjectionDistortion = 6
PixelsPerInchResolution = 1
RightShiftEvaluateOperator = 9
RectanglePrimitive = 3
AlphaChannel = 8
MagickPrimitiveOptions = 36
MagickLogEventOptions = 28
ImageRegistryType = 1
ButtCap = 1
BlackmanFilter = 7
PointFilter = 1
GrayVirtualPixelMethod = 11
AtopCompositeOp = 3
__GCONV_IGNORE_ERRORS = 2
CompareOverlayLayer = 4
GrayQuantum = 8
MagickStretchOptions = 41
StreamWarning = 340
ColorizeCompositeOp = 10
TypeWarning = 305
SoftLightCompositeOp = 46
StreamTransmitType = 3
MagickFalse = 0
LightenCompositeOp = 33
ErrorException = 400
XorCompositeOp = 54
PerspectiveDistortion = 5
BevelJoin = 3
ConfigureFatalError = 795
ArcPrimitive = 5
CorruptImageError = 425
BottomLeftOrientation = 4
BlackVirtualPixelMethod = 10
CopyBlackCompositeOp = 11
TransformEvent = 4096
SpreadPreview = 19
TileVirtualPixelMethod = 7
__GCONV_ILLEGAL_INPUT = 6
SrcCompositeOp = 48
CMYKQuantum = 5
FileOpenWarning = 330
DstCompositeOp = 22
ModuleEvent = 1024
MagickImageCoderModule = 0
PaletteType = 4
SrcAtopCompositeOp = 47
CondensedStretch = 4
RightBottomOrientation = 7
MagickFontsOptions = 19
ResetAlphaChannel = 3
ReduceNoisePreview = 13
ReflectSpread = 2
CopyMagentaCompositeOp = 16
SpiffPreview = 8
NormalStyle = 1
ShearPreview = 2
MagickClipPathOptions = 5
__GCONV_INTERNAL_ERROR = 9
UndefinedCompositeOp = 0
IndexChannel = 32
ChiNegative = 128
CirclePrimitive = 7
UndefinedLayer = 0
UndefinedDecoration = 0
DrawError = 460
RhoValue = 4
UndefinedReference = 0
WriteMode = 1
XiValue = 2
XiNegative = 32
MirrorVirtualPixelMethod = 5
UndefinedStyle = 0
RGBQuantum = 17
SrcOutCompositeOp = 50
MagickModeOptions = 31
OilPaintPreview = 27
TraceEvent = 1
SubtractCompositeOp = 52
SubtractEvaluateOperator = 11
ResourceLimitError = 400
FileOpenError = 430
NoneDispose = 1
LeftTopOrientation = 5
RoundCap = 2
PaletteMatteType = 5
RotatePreview = 1
GrayscalePreview = 10
NoCompliance = 0
HueCompositeOp = 31
MagickCoderOptions = 45
UndefinedEndian = 0
CharPixel = 1
GrayscaleType = 2
HermiteFilter = 4
CoderFatalError = 750
StringRegistryType = 3
CopyYellowCompositeOp = 19
MSBEndian = 2
UserSpaceOnUse = 2
WelshFilter = 17
ImageError = 465
RandomVirtualPixelMethod = 6
AspectValue = 8192
BezierPrimitive = 10
ExtraCondensedStretch = 3
UndefinedException = 0
MonitorWarning = 385
UndefinedMetric = 0
PsiNegative = 64
JPEGPreview = 29
MagickInterlaceOptions = 22
CopyOpacityCompositeOp = 17
ExpandedStretch = 7
OrEvaluateOperator = 8
SegmentPreview = 23
OutCompositeOp = 39
MagickCommandOptions = 7
NoEvents = 0
UndefinedGradient = 0
MagickBooleanOptions = 2
ReplaceMethod = 2
CenterAlign = 2
MeshInterpolatePixel = 6
MultiplyCompositeOp = 38
MagickAlphaOptions = 1
__codecvt_noconv = 3
SVGCompliance = 1
BlobFatalError = 735
MagickFormatOptions = 50
TypeError = 405
ConfigureEvent = 32
GammaPreview = 7
LocaleEvent = 512
NorthWestGravity = 1
CopyCompositeOp = 13
UndefinedAlign = 0
UndefinedEvaluateOperator = 0
ModulateCompositeOp = 37
DelegateFatalError = 715
DivideEvaluateOperator = 3
RemoveZeroLayer = 11
BlackQuantum = 2
BlueChannel = 4
PsiValue = 1
LanczosFilter = 13
CoalesceLayer = 1
DisplaceCompositeOp = 27
GIFInterlace = 5
MapResource = 4
GreaterValue = 32768
UndefinedCompression = 0
MattePrimitive = 12
XServerWarning = 380
MagickLineCapOptions = 25
BZipCompression = 2
MagickDistortOptions = 14
DeprecateEvent = 64
SemiCondensedStretch = 5
WhiteVirtualPixelMethod = 12
CharcoalDrawingPreview = 28
ImageTransmitType = 4
BlobWarning = 335
UndefinedVirtualPixelMethod = 0
BlobEvent = 4
LineThroughDecoration = 4
SolarizePreview = 20
PadSpread = 1
DarkenCompositeOp = 20
RootPath = 2
NearestNeighborInterpolatePixel = 7
UndefinedMethod = 0
LZWCompression = 8
BilevelType = 1
SaturationPreview = 5
__GCONV_NODB = 2
FillToBorderMethod = 4
RootMeanSquaredErrorMetric = 7
UndefinedResource = 0
NorthGravity = 2
FloodfillMethod = 3
MagickOrientationOptions = 34
X11Compliance = 2
AllEvents = 2147483647
MagickTypeOptions = 43
FrameMode = 1
NorthEastGravity = 3
UndefinedPathUnits = 0
SigmaValue = 8
UndefinedAlphaChannel = 0
GradientReference = 1
MissingDelegateError = 420
MagickGravityOptions = 20
LinearGradient = 1
DespecklePreview = 12
ConfigureError = 495
DstOverCompositeOp = 25
AffineDistortion = 1
LinePrimitive = 2
UnframeMode = 2
MagickMagicOptions = 54
TransparentVirtualPixelMethod = 8
NoThreadSupport = 0
OverCompositeOp = 40
OptimizeType = 10
UndefinedDispose = 0
MagickFontOptions = 49
ZipCompression = 10
SouthEastGravity = 9
IntegerInterpolatePixel = 5
ImageWarning = 365
HammingFilter = 6
OptimizeImageLayer = 7


# Pixel resolutions
PIXELS_PER_INCH = PixelsPerInchResolution
PIXELS_PER_CENTIMETER = PixelsPerCentimeterResolution

# Image filters
BESSEL_FILTER = BesselFilter
BLACKMAN_FILTER = BlackmanFilter
BOX_FILTER = BoxFilter
CATROM_FILTER = CatromFilter
CUBIC_FILTER = CubicFilter
GAUSSIAN_FILTER = GaussianFilter
HANNING_FILTER = HanningFilter
HERMITE_FILTER = HermiteFilter
LANCZOS_FILTER = LanczosFilter
MITCHELL_FILTER = MitchellFilter
POINT_FILTER = PointFilter
QUADRATIC_FILTER = QuadraticFilter
SINC_FILTER = SincFilter
TRIANGLE_FILTER = TriangleFilter

# Color spaces
CMYK_COLORSPACE = CMYKColorspace
CMY_COLORSPACE = CMYColorspace
OHTA_COLORSPACE = OHTAColorspace
LAB_COLORSPACE = LabColorspace
HWB_COLORSPACE = HWBColorspace
REC601YCBCR_COLORSPACE = Rec601YCbCrColorspace
REC709YCBCR_COLORSPACE = Rec709YCbCrColorspace
YIQ_COLORSPACE = YIQColorspace
TRANSPARENT_COLORSPACE = TransparentColorspace
YUV_COLORSPACE = YUVColorspace
YCC_COLORSPACE = YCCColorspace
SRGB_COLORSPACE = sRGBColorspace
HSL_COLORSPACE = HSLColorspace
REC601LUMA_COLORSPACE = Rec601LumaColorspace
HSB_COLORSPACE = HSBColorspace
REC709LUMA_COLORSPACE = Rec709LumaColorspace
GRAY_COLORSPACE = GRAYColorspace
LOG_COLORSPACE = LogColorspace
XYZ_COLORSPACE = XYZColorspace
YCBCR_COLORSPACE = YCbCrColorspace
RGB_COLORSPACE = RGBColorspace
YPBPR_COLORSPACE = YPbPrColorspace

# Channels
RED_CHANNEL = RedChannel
CYAN_CHANNEL = CyanChannel
GREEN_CHANNEL = GreenChannel
MAGENTA_CHANNEL = MagentaChannel
BLUE_CHANNEL = BlueChannel
YELLOW_CHANNEL = YellowChannel
ALPHA_CHANNEL = AlphaChannel
OPACITY_CHANNEL = OpacityChannel
BLACK_CHANNEL = BlackChannel
INDEX_CHANNEL = IndexChannel
ALL_CHANNELS = AllChannels

# Compression types
LOSSLESS_JPEG_COMPRESSION = LosslessJPEGCompression
JPEG_COMPRESSION = JPEGCompression
NO_COMPRESSION = NoCompression
JPEG2000_COMPRESSION = JPEG2000Compression
RLE_COMPRESSION = RLECompression
GROUP4_COMPRESSION = Group4Compression
FAX_COMPRESSION = FaxCompression
UNDEFINED_COMPRESSION = UndefinedCompression
BZIP_COMPRESSION = BZipCompression
LZW_COMPRESSION = LZWCompression
ZIP_COMPRESSION = ZipCompression

# Composite operations
MINUS_COMPOSITE_OP = MinusCompositeOp
ADD_COMPOSITE_OP = AddCompositeOp
IN_COMPOSITE_OP = InCompositeOp
DIFFERENCE_COMPOSITE_OP = DifferenceCompositeOp
PLUS_COMPOSITE_OP = PlusCompositeOp
BUMPMAP_COMPOSITE_OP = BumpmapCompositeOp
ATOP_COMPOSITE_OP = AtopCompositeOp
XOR_COMPOSITE_OP = XorCompositeOp
SUBTRACT_COMPOSITE_OP = SubtractCompositeOp
OUT_COMPOSITE_OP = OutCompositeOp
COPY_COMPOSITE_OP = CopyCompositeOp
DISPLACE_COMPOSITE_OP = DisplaceCompositeOp
OVER_COMPOSITE_OP = OverCompositeOp

# Evaluate operators
MAX_OPERATOR = MaxEvaluateOperator
MIN_OPERATOR = MinEvaluateOperator
MULTIPLY_OPERATOR = MultiplyEvaluateOperator
SET_OPERATOR = SetEvaluateOperator
XOR_OPERATOR = XorEvaluateOperator
AND_OPERATOR = AndEvaluateOperator
ADD_OPERATOR = AddEvaluateOperator
LEFT_SHIFT_OPERATOR = LeftShiftEvaluateOperator
RIGHT_SHIFT_OPERATOR = RightShiftEvaluateOperator
SUBTRACT_OPERATOR = SubtractEvaluateOperator
OR_OPERATOR = OrEvaluateOperator
DIVIDE_OPERATOR = DivideEvaluateOperator
